@@ -78,7 +78,7 @@ function( y , dat.scale = NULL , x=NULL , samp.pars = TRUE , alpha = NULL ,
     # draw regression parameter
     if ( samp.pars ){ 
         v <- vcov(mod)	
-        beta.star <- coef(mod) + mvrnorm( 1 , mu = rep(0, nrow(v) ) , Sigma = v )
+        beta.star <- coef(mod) + MASS::mvrnorm( 1 , mu = rep(0, nrow(v) ) , Sigma = v )
         # draw new fitted y
 		if ( x0ind ){
 			yfitted <- cbind(1,x0) %*% beta.star
